# netzeus-core-security
NetZeus Core Security Package

This module is used for microservices/plugins that want to implement security/authentication functions and authentication providers such as Azure AD or Google OAuth.